@@ -1,13 +1,14 @@
 """CalibrationConstantVersionApiTest class"""
 
-from dateutil.parser import parse as parse_dt
-from http import HTTPStatus
-import pytest
 import unittest
+from http import HTTPStatus
+
+import pytest
+from dateutil.parser import parse as parse_dt
 
 from .api_base import ApiBase
-from ..common.config_test import PHYSICAL_DETECTOR_UNIT
 from ..common import generators
+from ..common.config_test import PHYSICAL_DETECTOR_UNIT
 
 
 @pytest.mark.usefixtures('client_cls')
@@ -100,7 +101,8 @@ class CalibrationConstantVersionApiTest(ApiBase, unittest.TestCase):
                            'calibration_constant_id': [
                                'has already been taken'
                            ],
-                           'physical_detector_unit_id': ['has already been taken'],
+                           'physical_detector_unit_id': [
+                               'has already been taken'],
                            'begin_at': ['has already been taken']}}
 
         assert receive == expect
@@ -116,7 +118,8 @@ class CalibrationConstantVersionApiTest(ApiBase, unittest.TestCase):
         snapshot_at = ''
 
         resp = self.cal_client.get_calibration_constant_version_by_uk_api(
-            calibration_constant_id, physical_detector_unit_id, event_at, snapshot_at)
+            calibration_constant_id, physical_detector_unit_id, event_at,
+            snapshot_at)
         receive = self.load_response_content(resp)
 
         self.fields_validation(receive, expect)
@@ -190,5 +193,6 @@ class CalibrationConstantVersionApiTest(ApiBase, unittest.TestCase):
         assert expect['raw_data_location'] != expect_upd['raw_data_location']
         assert expect['description'] != expect_upd['description']
 
+
 if __name__ == '__main__':
     unittest.main()
